@@ -1,4 +1,5 @@
 from django.conf import settings
+from django.conf.urls import url
 from django.urls import include, path
 
 from pulp_ansible.app.galaxy.views import (
@@ -12,7 +13,7 @@ from pulp_ansible.app.galaxy.views import (
 )
 from pulp_ansible.app.galaxy.v3 import views as views_v3
 
-from pulp_ansible.app.viewsets import CollectionUploadViewSet
+from pulp_ansible.app.viewsets import CopyViewSet, CollectionUploadViewSet
 
 
 GALAXY_API_ROOT = getattr(settings, "GALAXY_API_ROOT", "pulp_ansible/galaxy/<path:path>/api/")
@@ -48,7 +49,7 @@ v3_urls = [
     ),
     path(
         "collections/<str:namespace>/<str:name>/",
-        views_v3.CollectionViewSet.as_view({"get": "retrieve", "put": "update"}),
+        views_v3.CollectionViewSet.as_view({"get": "retrieve", "patch": "update"}),
         name="collections-detail",
     ),
     path(
@@ -66,11 +67,6 @@ v3_urls = [
         views_v3.CollectionVersionDocsViewSet.as_view({"get": "retrieve"}),
         name="collection-versions-detail-docs",
     ),
-    path(
-        "collections/<str:namespace>/<str:name>/versions/<str:version>/certified/",
-        views_v3.CollectionVersionViewSet.as_view({"put": "set_certified"}),
-        name="collection-versions-set-certified",
-    ),
     path(
         "imports/collections/<uuid:pk>/",
         views_v3.CollectionImportViewSet.as_view({"get": "retrieve"}),
@@ -80,8 +76,9 @@ v3_urls = [
 
 urlpatterns = [
     path("ansible/collections/", CollectionUploadViewSet.as_view({"post": "create"})),
-    path(GALAXY_API_ROOT, GalaxyVersionView.as_view()),
     path(GALAXY_API_ROOT + "v1/", include(v1_urls)),
     path(GALAXY_API_ROOT + "v2/", include(v2_urls)),
     path(GALAXY_API_ROOT + "v3/", include(v3_urls)),
+    path(GALAXY_API_ROOT, GalaxyVersionView.as_view()),
+    url(r"^pulp/api/v3/ansible/copy/$", CopyViewSet.as_view({"post": "create"})),
 ]
